@@ -86,6 +86,9 @@ def score_by_period(
     if criterion == "std":
         current_score = std_score_by_period(right_dict, left_dict)
 
+    if criterion == "std_norm":
+        current_score = std_score_by_period(right_dict, left_dict, norm=True)
+
     if verbose:
         print(f"Score {criterion} by period: {current_score}")
 
@@ -95,7 +98,7 @@ def score_by_period(
         return np.max(current_score)
 
 
-def std_score_by_period(right_dict, left_dict):
+def std_score_by_period(right_dict, left_dict, norm=False):
     """
     Calculate the standard deviation score by period given two dictionaries that
     charactize the left and right leaf after the potential split.
@@ -115,35 +118,27 @@ def std_score_by_period(right_dict, left_dict):
             right_dict[key]["squared_sum"],
         )
 
-        total_count = left_dict[key]["count"] + right_dict[key]["count"]
-        current_score.append(
-            left_std * (left_dict[key]["count"] / total_count)
-            + right_std * (right_dict[key]["count"] / total_count)
-        )
+        if norm:
+            total_count = left_dict[key]["count"] + right_dict[key]["count"]
+            current_score.append(
+                left_std * (left_dict[key]["count"] / total_count)
+                + right_std * (right_dict[key]["count"] / total_count)
+            )
+        else:
+            current_score.append(
+                left_std * left_dict[key]["count"]
+                + right_std * right_dict[key]["count"]
+            )
 
     return current_score
 
-def gini_impurity_score(left_dict, right_dict):
-    left_proba = left_dict["sum"] / float(left_dict["count"])
-    left_gini = 1 - ((1 - left_proba) ** 2 + (left_proba) ** 2)
 
-    right_proba = right_dict["sum"] / float(right_dict["count"])
-    right_gini = 1 - ((1 - right_proba) ** 2 + (right_proba) ** 2)
-
-    total_count = left_dict["count"] + right_dict["count"]
-    return left_gini * (left_dict["count"] / total_count)\
-        + right_gini * (right_dict["count"] / total_count)
-
-
-def gini_impurity_score_by_period(right_dict, left_dict, include_aggregated=False):
+def gini_impurity_score_by_period(right_dict, left_dict):
     """
     Calculate the gini impurity score by period given two dictionaries that
     charactize the left and right leaf after the potential split.
     """
     current_score = []
-    agg_dict = {"left": {"sum": 0, "count": 0},
-                "right":{"sum": 0, "count": 0}}
-
     for key in right_dict.keys():
 
         left_proba = left_dict[key]["sum"] / float(left_dict[key]["count"])
@@ -158,14 +153,6 @@ def gini_impurity_score_by_period(right_dict, left_dict, include_aggregated=Fals
             + right_gini * (right_dict[key]["count"] / total_count)
         )
 
-        if include_aggregated:
-            agg_dict["left"]["sum"] += left_dict[key]["sum"]
-            agg_dict["left"]["count"] += left_dict[key]["count"]
-            agg_dict["right"]["sum"] += right_dict[key]["sum"]
-            agg_dict["right"]["count"] += right_dict[key]["count"]
-
-    if include_aggregated:
-        current_score.append(gini_impurity_score(agg_dict["left"], agg_dict["right"]))
     return current_score
 
 
